@@ -23,21 +23,18 @@
  *
  */
 
-#include <popt.h>
 #include <gtk/gtk.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
 
-poptContext popt;
 gboolean option_timeout_kill;
 gboolean option_theme_colors;
 
-static struct poptOption options[] = {
-	{ "kill", '\0', POPT_ARG_NONE, &option_timeout_kill, 0,
+static const GOptionEntry options[] = {
+	{ "kill", '\0', 0, G_OPTION_ARG_NONE, &option_timeout_kill,
 	  "Kill ourselves after 1 second timeout", NULL},
-	{ "theme-colors", '\0', POPT_ARG_NONE, &option_theme_colors, 0,
+	{ "theme-colors", '\0', 0, G_OPTION_ARG_NONE, &option_theme_colors,
 	  "Use only the theme colors", NULL},
-	POPT_AUTOHELP
 	{ NULL }
 };
 
@@ -219,9 +216,21 @@ my_print (void)
 int
 main (int argc, char * argv[])
 {
-	popt = poptGetContext ("test-preview", argc, (const char **)argv, options, 0);
-	poptGetNextOpt (popt);
-	
+	GOptionContext *goption_context;
+	GError *error = NULL;
+
+	goption_context = g_option_context_new (NULL);
+	g_option_context_add_main_entries (goption_context, options, NULL);
+	g_option_context_parse (goption_context, &argc, &argv, &error);
+	g_option_context_free (goption_context);
+
+	if (error != NULL) {
+		g_printerr ("%s\n", error->message);
+		g_error_free(error);
+		g_print ("Run '%s --help' to see a full list of available command line options.\n", g_get_prgname());
+		exit (1);
+	}
+
 	gtk_init (&argc, &argv);
 	
 	my_print ();
